@@ -4,6 +4,7 @@
 import subprocess
 import json
 import logging
+from envchain_python.config import DEFAULT_ENVCHAIN_COMMAND, __version__
 
 # Configure a logger for the library.
 # Applications using this library can configure handlers and levels for this logger.
@@ -79,7 +80,9 @@ class EnvchainError(Exception):
 
 
 def _run_envchain_command(
-    cmd_list: list[str], input_payload_str: str | None = None
+    cmd_list: list[str],
+    input_payload_str: str | None = None,
+    envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND,
 ) -> tuple[str, str]:
     """
     Helper function to run envchain commands and handle common errors.
@@ -87,6 +90,7 @@ def _run_envchain_command(
     Args:
         cmd_list: The command and its arguments as a list of strings.
         input_payload_str: Optional string to pass to the command's stdin.
+        envchain_cmd: The envchain command to use (default: "envchain")
 
     Returns:
         A tuple (stdout_str, stderr_str).
@@ -95,6 +99,9 @@ def _run_envchain_command(
         EnvchainError: If envchain is not found or the command returns a non-zero exit code,
                       or if stderr indicates a namespace is not defined.
     """
+    # Replace the first element (default 'envchain') with the specified command
+    cmd_list[0] = envchain_cmd
+
     logger.debug(f"Executing envchain command: {' '.join(cmd_list)}")
     if input_payload_str is not None:
         num_lines = len(input_payload_str.splitlines())
@@ -152,6 +159,7 @@ def set_vars(
     namespace: str,
     variables: dict[str, str | None],
     require_passphrase: bool = False,
+    envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND,
 ) -> None:
     """
     Sets variables in the specified envchain namespace.
@@ -208,7 +216,7 @@ def set_vars(
 
     input_payload_str = "".join(input_lines)
 
-    envchain_cmd_list = ["envchain", "--set"]
+    envchain_cmd_list = [envchain_cmd, "--set"]
     if require_passphrase:
         envchain_cmd_list.append("--require-passphrase")
     # if noecho:
@@ -267,7 +275,11 @@ def set_var(namespace: str, key: str, value: str | None) -> None:
     return
 
 
-def unset_vars(namespace: str, variable_keys: list[str] | str) -> None:
+def unset_vars(
+    namespace: str,
+    variable_keys: list[str] | str,
+    envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND,
+) -> None:
     """
     Unsets variables in the specified envchain namespace.
 
@@ -300,7 +312,7 @@ def unset_vars(namespace: str, variable_keys: list[str] | str) -> None:
             raise TypeError("All variable keys must be non-empty strings.")
         stripped_keys.append(key.strip())
 
-    envchain_cmd_list = ["envchain", "--unset", namespace]
+    envchain_cmd_list = [envchain_cmd, "--unset", namespace]
     envchain_cmd_list.extend(stripped_keys)
 
     logger.info(
@@ -318,7 +330,7 @@ def unset_vars(namespace: str, variable_keys: list[str] | str) -> None:
         logger.warning(f"envchain stderr (unset):\n{stderr}")
 
 
-def list_namespaces() -> list[str]:
+def list_namespaces(envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND) -> list[str]:
     """
     Lists all envchain namespaces.
 
@@ -329,7 +341,7 @@ def list_namespaces() -> list[str]:
     Raises:
         EnvchainError: If the envchain command itself fails.
     """
-    envchain_cmd_list = ["envchain", "--list"]
+    envchain_cmd_list = [envchain_cmd, "--list"]
     logger.info("Listing all envchain namespaces.")
 
     stdout, stderr = _run_envchain_command(envchain_cmd_list)
@@ -343,7 +355,9 @@ def list_namespaces() -> list[str]:
     return namespaces
 
 
-def delete_namespace(namespace: str) -> None:
+def delete_namespace(
+    namespace: str, envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND
+) -> None:
     """
     Deletes an envchain namespace by unsetting all keys in it.
 
@@ -360,16 +374,18 @@ def delete_namespace(namespace: str) -> None:
     namespace = namespace.strip()
 
     # Get keys via list_keys_in_namespace, which now raises for nonexistent
-    keys = list_keys_in_namespace(namespace)
+    keys = list_keys_in_namespace(namespace, envchain_cmd=envchain_cmd)
     if not keys:
         raise EnvchainError(
             f"Namespace '{namespace}' is empty. Cannot delete an empty namespace."
         )
-    unset_vars(namespace, keys)
+    unset_vars(namespace, keys, envchain_cmd=envchain_cmd)
     logger.info(f"Successfully deleted all keys from namespace '{namespace}'.")
 
 
-def list_keys_in_namespace(namespace: str) -> list[str]:
+def list_keys_in_namespace(
+    namespace: str, envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND
+) -> list[str]:
     """
     Lists all keys in the specified envchain namespace.
 
@@ -387,7 +403,7 @@ def list_keys_in_namespace(namespace: str) -> list[str]:
         raise ValueError("Namespace must be a non-empty string.")
     namespace = namespace.strip()
 
-    envchain_cmd_list = ["envchain", "--list", namespace]
+    envchain_cmd_list = [envchain_cmd, "--list", namespace]
     logger.info(f"Listing keys in envchain namespace '{namespace}'.")
 
     stdout, stderr = _run_envchain_command(envchain_cmd_list)
@@ -398,7 +414,9 @@ def list_keys_in_namespace(namespace: str) -> list[str]:
     return keys
 
 
-def get_vars(namespace: str, *variable_keys: str) -> dict[str, str]:
+def get_vars(
+    namespace: str, *variable_keys: str, envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND
+) -> dict[str, str]:
     """
     Retrieves specified variables from an envchain namespace.
     Uses `envchain --list --show-value <namespace>` to get key-value pairs.
@@ -433,7 +451,7 @@ def get_vars(namespace: str, *variable_keys: str) -> dict[str, str]:
             )
         keys_to_filter.append(key_filter.strip())
 
-    envchain_cmd_list = ["envchain", "--list", "--show-value", namespace]
+    envchain_cmd_list = [envchain_cmd, "--list", "--show-value", namespace]
 
     logger.info(f"Getting variables from envchain namespace '{namespace}'.")
     if keys_to_filter:
@@ -472,7 +490,9 @@ def get_vars(namespace: str, *variable_keys: str) -> dict[str, str]:
     return retrieved_vars
 
 
-def get_var(namespace: str, key: str) -> str | None:
+def get_var(
+    namespace: str, key: str, envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND
+) -> str | None:
     """
     Retrieves a single variable from an envchain namespace.
 
@@ -494,5 +514,5 @@ def get_var(namespace: str, key: str) -> str | None:
         raise ValueError("Key must be a non-empty string.")
     key = key.strip()
 
-    retrieved_vars = get_vars(namespace, key)
+    retrieved_vars = get_vars(namespace, key, envchain_cmd=envchain_cmd)
     return retrieved_vars.get(key)  # Returns None if key is not found
